summaryrefslogtreecommitdiffstats
path: root/libkdeedu
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:18:52 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:18:52 +0000
commit648ba4a456d3aad2825193ff8f3bd52a875783b5 (patch)
tree0b50d2253a0c85238cc4dcba5c4f949de3f0eb15 /libkdeedu
parent98a12d05a48814bec3870b9a6d5865475cfa1c95 (diff)
downloadtdeedu-648ba4a456d3aad2825193ff8f3bd52a875783b5.tar.gz
tdeedu-648ba4a456d3aad2825193ff8f3bd52a875783b5.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1212481 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdeedu')
-rw-r--r--libkdeedu/extdate/extcalendarsystem.cpp2
-rw-r--r--libkdeedu/extdate/extcalendarsystem.h2
-rw-r--r--libkdeedu/extdate/extcalendarsystemgregorian.cpp4
-rw-r--r--libkdeedu/extdate/extcalendarsystemgregorian.h2
-rw-r--r--libkdeedu/extdate/extdatepicker.cpp28
-rw-r--r--libkdeedu/extdate/extdatepicker.h6
-rw-r--r--libkdeedu/extdate/extdatetbl.cpp58
-rw-r--r--libkdeedu/extdate/extdatetbl.h8
-rw-r--r--libkdeedu/extdate/extdatetime.cpp66
-rw-r--r--libkdeedu/extdate/extdatetime.h6
-rw-r--r--libkdeedu/extdate/extdatetimeedit.cpp122
-rw-r--r--libkdeedu/extdate/extdatetimeedit.h12
-rw-r--r--libkdeedu/extdate/extdatewidget.cpp12
-rw-r--r--libkdeedu/extdate/test_extdate.cc16
-rw-r--r--libkdeedu/extdate/testwidget.cpp4
-rw-r--r--libkdeedu/kdeeduplot/kplotwidget.cpp2
-rw-r--r--libkdeedu/kdeeduplot/kplotwidget.h10
-rw-r--r--libkdeedu/kdeeduui/kdeeduglossary.cpp36
-rw-r--r--libkdeedu/kdeeduui/kdeeduglossary.h4
-rw-r--r--libkdeedu/kdeeduui/kedusimpleentrydlgForm.ui16
20 files changed, 208 insertions, 208 deletions
diff --git a/libkdeedu/extdate/extcalendarsystem.cpp b/libkdeedu/extdate/extcalendarsystem.cpp
index 976301a8..f453bb6f 100644
--- a/libkdeedu/extdate/extcalendarsystem.cpp
+++ b/libkdeedu/extdate/extcalendarsystem.cpp
@@ -4,7 +4,7 @@
Copyright (c) 2004 Jason Harris <jharris@30doradus.org>
This class has been derived from ExtCalendarSystem;
- the changesd made just tqreplace TQDate objects with ExtDate objects.
+ the changesd made just replace TQDate objects with ExtDate objects.
These changes by Jason Harris <jharris@30doradus.org>
This library is free software; you can redistribute it and/or
diff --git a/libkdeedu/extdate/extcalendarsystem.h b/libkdeedu/extdate/extcalendarsystem.h
index 1ec6cb94..be7ba336 100644
--- a/libkdeedu/extdate/extcalendarsystem.h
+++ b/libkdeedu/extdate/extcalendarsystem.h
@@ -4,7 +4,7 @@
Copyright (c) 2004 Jason Harris <jharris@30doradus.org>
This class has been derived from KCalendarSystem;
- the changesd made just tqreplace TQDate objects with ExtDate objects.
+ the changesd made just replace TQDate objects with ExtDate objects.
These changes by Jason Harris <jharris@30doradus.org>
This library is free software; you can redistribute it and/or
diff --git a/libkdeedu/extdate/extcalendarsystemgregorian.cpp b/libkdeedu/extdate/extcalendarsystemgregorian.cpp
index d19c86de..47338f4b 100644
--- a/libkdeedu/extdate/extcalendarsystemgregorian.cpp
+++ b/libkdeedu/extdate/extcalendarsystemgregorian.cpp
@@ -4,7 +4,7 @@
Copyright (c) 2004 Jason Harris <jharris@30doradus.org>
This class has been derived from KCalendarSystemGregorian;
- the changesd made just tqreplace TQDate objects with ExtDate objects.
+ the changesd made just replace TQDate objects with ExtDate objects.
These changes by Jason Harris <jharris@30doradus.org>
This library is free software; you can redistribute it and/or
@@ -294,7 +294,7 @@ int ExtCalendarSystemGregorian::weekDayOfPray() const
TQString ExtCalendarSystemGregorian::calendarName() const
{
- return TQString::tqfromLatin1("gregorian");
+ return TQString::fromLatin1("gregorian");
}
bool ExtCalendarSystemGregorian::isLunar() const
diff --git a/libkdeedu/extdate/extcalendarsystemgregorian.h b/libkdeedu/extdate/extcalendarsystemgregorian.h
index fd13e04b..6d1035c9 100644
--- a/libkdeedu/extdate/extcalendarsystemgregorian.h
+++ b/libkdeedu/extdate/extcalendarsystemgregorian.h
@@ -4,7 +4,7 @@
Copyright (c) 2004 Jason Harris <jharris@30doradus.org>
This class has been derived from KCalendarSystemGregorian;
- the changesd made just tqreplace TQDate objects with ExtDate objects.
+ the changesd made just replace TQDate objects with ExtDate objects.
These changes by Jason Harris <jharris@30doradus.org>
This library is free software; you can redistribute it and/or
diff --git a/libkdeedu/extdate/extdatepicker.cpp b/libkdeedu/extdate/extdatepicker.cpp
index 87e56881..ad524863 100644
--- a/libkdeedu/extdate/extdatepicker.cpp
+++ b/libkdeedu/extdate/extdatepicker.cpp
@@ -98,7 +98,7 @@ ExtDatePicker::ExtDatePicker(TQWidget *parent, ExtDate dt, const char *name, WFl
ExtDatePicker::ExtDatePicker( TQWidget *parent, const char *name )
: TQFrame(parent,name)
{
- init( ExtDate::tqcurrentDate() );
+ init( ExtDate::currentDate() );
}
void ExtDatePicker::init( const ExtDate &dt )
@@ -166,17 +166,17 @@ void ExtDatePicker::init( const ExtDate &dt )
if ( TQApplication::reverseLayout() )
{
- yearForward->setIconSet(BarIconSet(TQString::tqfromLatin1("2leftarrow")));
- yearBackward->setIconSet(BarIconSet(TQString::tqfromLatin1("2rightarrow")));
- monthForward->setIconSet(BarIconSet(TQString::tqfromLatin1("1leftarrow")));
- monthBackward->setIconSet(BarIconSet(TQString::tqfromLatin1("1rightarrow")));
+ yearForward->setIconSet(BarIconSet(TQString::fromLatin1("2leftarrow")));
+ yearBackward->setIconSet(BarIconSet(TQString::fromLatin1("2rightarrow")));
+ monthForward->setIconSet(BarIconSet(TQString::fromLatin1("1leftarrow")));
+ monthBackward->setIconSet(BarIconSet(TQString::fromLatin1("1rightarrow")));
}
else
{
- yearForward->setIconSet(BarIconSet(TQString::tqfromLatin1("2rightarrow")));
- yearBackward->setIconSet(BarIconSet(TQString::tqfromLatin1("2leftarrow")));
- monthForward->setIconSet(BarIconSet(TQString::tqfromLatin1("1rightarrow")));
- monthBackward->setIconSet(BarIconSet(TQString::tqfromLatin1("1leftarrow")));
+ yearForward->setIconSet(BarIconSet(TQString::fromLatin1("2rightarrow")));
+ yearBackward->setIconSet(BarIconSet(TQString::fromLatin1("2leftarrow")));
+ monthForward->setIconSet(BarIconSet(TQString::fromLatin1("1rightarrow")));
+ monthBackward->setIconSet(BarIconSet(TQString::fromLatin1("1leftarrow")));
}
connect(table, TQT_SIGNAL(dateChanged(const ExtDate&)), TQT_SLOT(dateChangedSlot(const ExtDate&)));
connect(table, TQT_SIGNAL(tableClicked()), TQT_SLOT(tableClickedSlot()));
@@ -386,7 +386,7 @@ ExtDatePicker::selectYearClicked()
KPopupFrame* popup = new KPopupFrame(this);
ExtDateInternalYearSelector* picker = new ExtDateInternalYearSelector(popup);
// -----
- picker->resize(picker->tqsizeHint());
+ picker->resize(picker->sizeHint());
popup->setMainWidget(picker);
connect(picker, TQT_SIGNAL(closeMe(int)), popup, TQT_SLOT(close(int)));
picker->setFocus();
@@ -446,13 +446,13 @@ ExtDatePicker::lineEnterPressed()
void
ExtDatePicker::todayButtonClicked()
{
- setDate(ExtDate::tqcurrentDate());
+ setDate(ExtDate::currentDate());
}
QSize
-ExtDatePicker::tqsizeHint() const
+ExtDatePicker::sizeHint() const
{
- return TQWidget::tqsizeHint();
+ return TQWidget::sizeHint();
}
void
@@ -512,7 +512,7 @@ ExtDatePicker::setCloseButton( bool enable )
TQToolTip::add(d->closeButton, i18n("Close"));
d->closeButton->setPixmap( SmallIcon("remove") );
connect( d->closeButton, TQT_SIGNAL( clicked() ),
- tqtopLevelWidget(), TQT_SLOT( close() ) );
+ topLevelWidget(), TQT_SLOT( close() ) );
}
else {
delete d->closeButton;
diff --git a/libkdeedu/extdate/extdatepicker.h b/libkdeedu/extdate/extdatepicker.h
index 216df369..8c745b52 100644
--- a/libkdeedu/extdate/extdatepicker.h
+++ b/libkdeedu/extdate/extdatepicker.h
@@ -61,7 +61,7 @@ public:
* initially.
**/
ExtDatePicker(TQWidget *parent=0,
- ExtDate=ExtDate::tqcurrentDate(),
+ ExtDate=ExtDate::currentDate(),
const char *name=0);
/** The usual constructor. The given date will be displayed
@@ -91,7 +91,7 @@ public:
* size hint, try adding 28 to each of the reported numbers of
* pixels.
**/
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
/**
* Sets the date.
@@ -137,7 +137,7 @@ public:
/**
* By calling this method with @p enable = true, ExtDatePicker will show
* a little close-button in the upper button-row. Clicking the
- * close-button will cause the ExtDatePicker's tqtopLevelWidget()'s close()
+ * close-button will cause the ExtDatePicker's topLevelWidget()'s close()
* method being called. This is mostly useful for toplevel datepickers
* without a window manager decoration.
* @see hasCloseButton
diff --git a/libkdeedu/extdate/extdatetime.h b/libkdeedu/extdate/extdatetime.h
index c398b7c5..0830af83 100644
--- a/libkdeedu/extdate/extdatetime.h
+++ b/libkdeedu/extdate/extdatetime.h
@@ -88,7 +88,7 @@ public:
bool operator>( const ExtDate &d ) const { return m_jd > d.jd(); }
bool operator>=( const ExtDate &d ) const { return m_jd >= d.jd(); }
- static ExtDate tqcurrentDate( Qt::TimeSpec ts = Qt::LocalTime );
+ static ExtDate currentDate( Qt::TimeSpec ts = Qt::LocalTime );
#ifndef QT_NO_DATESTRING
static ExtDate fromString( const TQString &s );
static ExtDate fromString( const TQString &s, Qt::DateFormat f );
@@ -162,8 +162,8 @@ public:
bool operator>( const ExtDateTime &dt ) const;
bool operator>=( const ExtDateTime &dt ) const;
- static ExtDateTime tqcurrentDateTime();
- static ExtDateTime tqcurrentDateTime( Qt::TimeSpec );
+ static ExtDateTime currentDateTime();
+ static ExtDateTime currentDateTime( Qt::TimeSpec );
#ifndef QT_NO_DATESTRING
static ExtDateTime fromString( const TQString &s );
static ExtDateTime fromString( const TQString &s, Qt::DateFormat f );
diff --git a/libkdeedu/extdate/extdatetimeedit.h b/libkdeedu/extdate/extdatetimeedit.h
index d0998362..4bcf78c8 100644
--- a/libkdeedu/extdate/extdatetimeedit.h
+++ b/libkdeedu/extdate/extdatetimeedit.h
@@ -81,8 +81,8 @@ public:
YMD /**< Year-Month-Day, also the default */,
YDM /**< Year-Day-Month @deprecated Included for completeness. */ };
- TQSize tqsizeHint() const;
- TQSize tqminimumSizeHint() const;
+ TQSize sizeHint() const;
+ TQSize minimumSizeHint() const;
public slots:
virtual void setDate( const ExtDate& date );
@@ -167,8 +167,8 @@ private:
// QTimeEdit( const TQTime& time, TQWidget* parent=0, const char* name=0 );
// ~QTimeEdit();
//
-// TQSize tqsizeHint() const;
-// TQSize tqminimumSizeHint() const;
+// TQSize sizeHint() const;
+// TQSize minimumSizeHint() const;
//
// public slots:
// virtual void setTime( const TQTime& time );
@@ -239,8 +239,8 @@ public:
const char* name=0 );
~ExtDateTimeEdit();
- TQSize tqsizeHint() const;
- TQSize tqminimumSizeHint() const;
+ TQSize sizeHint() const;
+ TQSize minimumSizeHint() const;
public slots:
virtual void setDateTime( const ExtDateTime & dt );
diff --git a/libkdeedu/extdate/extdatewidget.cpp b/libkdeedu/extdate/extdatewidget.cpp
index 93947dbc..5f5d19d6 100644
--- a/libkdeedu/extdate/extdatewidget.cpp
+++ b/libkdeedu/extdate/extdatewidget.cpp
@@ -36,7 +36,7 @@ public:
ExtDateWidgetSpinBox(int min, int max, TQWidget *parent)
: TQSpinBox(min, max, 1, parent)
{
- editor()->tqsetAlignment(AlignRight);
+ editor()->setAlignment(AlignRight);
}
};
@@ -56,7 +56,7 @@ public:
ExtDateWidget::ExtDateWidget( TQWidget *parent, const char *name )
: TQWidget( parent, name )
{
- init(ExtDate::tqcurrentDate());
+ init(ExtDate::currentDate());
setDate(ExtDate());
}
@@ -74,8 +74,8 @@ ExtDateWidget::ExtDateWidget( const ExtDate &date, TQWidget *parent,
// {
// d = new ExtDateWidgetPrivate;
// KLocale *locale = KGlobal::locale();
-// TQHBoxLayout *tqlayout = new TQHBoxLayout(this, 0, KDialog::spacingHint());
-// tqlayout->setAutoAdd(true);
+// TQHBoxLayout *layout = new TQHBoxLayout(this, 0, KDialog::spacingHint());
+// layout->setAutoAdd(true);
// d->m_day = new ExtDateWidgetSpinBox(1, 1, this);
// d->m_month = new TQComboBox(false, this);
// for (int i = 1; ; ++i)
@@ -98,8 +98,8 @@ void ExtDateWidget::init(const ExtDate& date)
{
d = new ExtDateWidgetPrivate;
//KLocale *locale = KGlobal::locale();
- TQHBoxLayout *tqlayout = new TQHBoxLayout(this, 0, KDialog::spacingHint());
- tqlayout->setAutoAdd(true);
+ TQHBoxLayout *layout = new TQHBoxLayout(this, 0, KDialog::spacingHint());
+ layout->setAutoAdd(true);
d->m_day = new ExtDateWidgetSpinBox(1, 1, this);
d->m_month = new TQComboBox(false, this);
for (int i = 1; ; ++i)
diff --git a/libkdeedu/extdate/test_extdate.cc b/libkdeedu/extdate/test_extdate.cc
index 0cb212d9..d63d1558 100644
--- a/libkdeedu/extdate/test_extdate.cc
+++ b/libkdeedu/extdate/test_extdate.cc
@@ -277,16 +277,16 @@ void test6()
void test7()
{
std::cout << "Express the current date:\n" << std::endl;
- TQDate q = TQDate::tqcurrentDate(Qt::LocalTime);
- ExtDate e = ExtDate::tqcurrentDate(Qt::TimeSpec(Qt::LocalTime));
+ TQDate q = TQDate::currentDate(Qt::LocalTime);
+ ExtDate e = ExtDate::currentDate(Qt::TimeSpec(Qt::LocalTime));
std::cout << "Qt::LocalTime :: ExtDate : " << e.toString().local8Bit() << " TQDate : "
<< q.toString().local8Bit() << std::endl;
- q = TQDate::tqcurrentDate(Qt::UTC);
- e = ExtDate::tqcurrentDate(Qt::UTC);
+ q = TQDate::currentDate(Qt::UTC);
+ e = ExtDate::currentDate(Qt::UTC);
std::cout << "Qt::UTC :: ExtDate : " << e.toString().local8Bit() << " TQDate : "
<< q.toString().local8Bit() << std::endl;
- q = TQDate::tqcurrentDate();
- e = ExtDate::tqcurrentDate();
+ q = TQDate::currentDate();
+ e = ExtDate::currentDate();
std::cout << "<default> :: ExtDate : " << e.toString().local8Bit() << " TQDate : "
<< q.toString().local8Bit() << std::endl;
std::cout << "--------------------" << std::endl;
@@ -311,8 +311,8 @@ void test8() {
void test9() {
std::cout << "TQDateTime : ExtDateTime: \n" << std::endl;
- TQDateTime q = TQDateTime::tqcurrentDateTime();
- ExtDateTime e = ExtDateTime::tqcurrentDateTime();
+ TQDateTime q = TQDateTime::currentDateTime();
+ ExtDateTime e = ExtDateTime::currentDateTime();
std::cout << q.toString().local8Bit() << " : " << e.toString().local8Bit() << std::endl;
std::cout << "--------------------" << std::endl;
diff --git a/libkdeedu/extdate/testwidget.cpp b/libkdeedu/extdate/testwidget.cpp
index a6489cce..0267ddeb 100644
--- a/libkdeedu/extdate/testwidget.cpp
+++ b/libkdeedu/extdate/testwidget.cpp
@@ -39,8 +39,8 @@ TestWidget::TestWidget( TQWidget *p=0, const char *name=0 ) : KMainWindow( p, na
edpEdit = new KLineEdit(w);
edpEdit->setReadOnly( TRUE );
- kdw = new KDateWidget( TQDate::tqcurrentDate(), w );
- edw = new ExtDateWidget( ExtDate::tqcurrentDate(), w );
+ kdw = new KDateWidget( TQDate::currentDate(), w );
+ edw = new ExtDateWidget( ExtDate::currentDate(), w );
glay->addWidget( kdpLabel, 0, 0 );
glay->addWidget( edpLabel, 0, 1 );
diff --git a/libkdeedu/kdeeduplot/kplotwidget.cpp b/libkdeedu/kdeeduplot/kplotwidget.cpp
index 321dd444..99e9b321 100644
--- a/libkdeedu/kdeeduplot/kplotwidget.cpp
+++ b/libkdeedu/kdeeduplot/kplotwidget.cpp
@@ -223,7 +223,7 @@ void KPlotWidget::drawObjects( TQPainter *p ) {
double KPlotWidget::dmod( double a, double b ) { return ( b * ( ( a / b ) - int( a / b ) ) ); }
void KPlotWidget::drawBox( TQPainter *p ) {
- //First, fill in padding region with bgColor() to tqmask out-of-bounds plot data
+ //First, fill in padding region with bgColor() to mask out-of-bounds plot data
p->setPen( bgColor() );
p->setBrush( bgColor() );
diff --git a/libkdeedu/kdeeduui/kdeeduglossary.cpp b/libkdeedu/kdeeduui/kdeeduglossary.cpp
index 2b6dab8f..1b0902b1 100644
--- a/libkdeedu/kdeeduui/kdeeduglossary.cpp
+++ b/libkdeedu/kdeeduui/kdeeduglossary.cpp
@@ -41,25 +41,25 @@ Glossary::~Glossary()
bool Glossary::loadLayout( TQDomDocument &Document, const KURL& url )
{
- TQFile tqlayoutFile( url.path() );
+ TQFile layoutFile( url.path() );
- if (!tqlayoutFile.exists())
+ if (!layoutFile.exists())
{
- kdDebug() << "no such file: " << tqlayoutFile.name() << endl;
+ kdDebug() << "no such file: " << layoutFile.name() << endl;
return false;
}
- if (!tqlayoutFile.open(IO_ReadOnly))
+ if (!layoutFile.open(IO_ReadOnly))
return false;
///Check if document is well-formed
- if (!Document.setContent(&tqlayoutFile))
+ if (!Document.setContent(&layoutFile))
{
kdDebug() << "wrong xml" << endl;
- tqlayoutFile.close();
+ layoutFile.close();
return false;
}
- tqlayoutFile.close();
+ layoutFile.close();
return true;
}
@@ -100,8 +100,8 @@ void Glossary::fixImagePath()
for ( ; it != itEnd ; ++it )
{
- ( *it )->setDesc( ( *it )->desc().tqreplace("[img]", firstpart ) );
- ( *it )->setDesc( ( *it )->desc().tqreplace("[/img]", "\" />" ) );
+ ( *it )->setDesc( ( *it )->desc().replace("[img]", firstpart ) );
+ ( *it )->setDesc( ( *it )->desc().replace("[/img]", "\" />" ) );
}
}
@@ -136,15 +136,15 @@ TQValueList<GlossaryItem*> Glossary::readItems( TQDomDocument &itemDocument )
item->setName( i18n( nameNode.toElement( ).text().utf8() ) );
- item->setDesc( desc.tqreplace("[b]", "<b>" ) );
- item->setDesc( item->desc().tqreplace("[/b]", "</b>" ) );
- item->setDesc( item->desc().tqreplace("[i]", "<i>" ) );
- item->setDesc( item->desc().tqreplace("[/i]", "</i>" ) );
- item->setDesc( item->desc().tqreplace("[sub]", "<sub>" ) );
- item->setDesc( item->desc().tqreplace("[/sub]", "</sub>" ) );
- item->setDesc( item->desc().tqreplace("[sup]", "<sup>" ) );
- item->setDesc( item->desc().tqreplace("[/sup]", "</sup>" ) );
- item->setDesc( item->desc().tqreplace("[br]", "<br />" ) );
+ item->setDesc( desc.replace("[b]", "<b>" ) );
+ item->setDesc( item->desc().replace("[/b]", "</b>" ) );
+ item->setDesc( item->desc().replace("[i]", "<i>" ) );
+ item->setDesc( item->desc().replace("[/i]", "</i>" ) );
+ item->setDesc( item->desc().replace("[sub]", "<sub>" ) );
+ item->setDesc( item->desc().replace("[/sub]", "</sub>" ) );
+ item->setDesc( item->desc().replace("[sup]", "<sup>" ) );
+ item->setDesc( item->desc().replace("[/sup]", "</sup>" ) );
+ item->setDesc( item->desc().replace("[br]", "<br />" ) );
refNodeList = refNode.elementsByTagName( "refitem" );
for ( uint it = 0; it < refNodeList.count(); it++ )
diff --git a/libkdeedu/kdeeduui/kdeeduglossary.h b/libkdeedu/kdeeduui/kdeeduglossary.h
index bc9113cc..44b0cf85 100644
--- a/libkdeedu/kdeeduui/kdeeduglossary.h
+++ b/libkdeedu/kdeeduui/kdeeduglossary.h
@@ -137,7 +137,7 @@ class Glossary
TQString m_backgroundpicture;
/**
- * tqreplaces the [img]-pseudocode with valid html. The path where
+ * replaces the [img]-pseudocode with valid html. The path where
* the pictures are stored will be used for pictures
*/
void fixImagePath();
@@ -148,7 +148,7 @@ class Glossary
TQString m_picturepath;
/**
- * Load the tqlayout from an XML file.
+ * Load the layout from an XML file.
*
* @param doc The TQDomDocument which will contain the read XML
* contents.
diff --git a/libkdeedu/kdeeduui/kedusimpleentrydlgForm.ui b/libkdeedu/kdeeduui/kedusimpleentrydlgForm.ui
index da44ab8c..32fa6b68 100644
--- a/libkdeedu/kdeeduui/kedusimpleentrydlgForm.ui
+++ b/libkdeedu/kdeeduui/kedusimpleentrydlgForm.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>Simple_entry_dialog</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -19,7 +19,7 @@
<property name="name">
<cstring>e_original</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>40</x>
<y>80</y>
@@ -32,7 +32,7 @@
<property name="name">
<cstring>e_translation</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>40</x>
<y>180</y>
@@ -45,7 +45,7 @@
<property name="name">
<cstring>PushButton1</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>50</x>
<y>360</y>
@@ -61,7 +61,7 @@
<property name="name">
<cstring>PushButton1_2</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>460</x>
<y>360</y>
@@ -77,7 +77,7 @@
<property name="name">
<cstring>TextLabel1</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>40</x>
<y>50</y>
@@ -93,7 +93,7 @@
<property name="name">
<cstring>TextLabel1_2</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>40</x>
<y>150</y>
@@ -106,5 +106,5 @@
</property>
</widget>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/libkdeedu/extdate/extdatetbl.cpp b/libkdeedu/extdate/extdatetbl.cpp
index 213ee277..ca403a68 100644
--- a/libkdeedu/extdate/extdatetbl.cpp
+++ b/libkdeedu/extdate/extdatetbl.cpp
@@ -124,7 +124,7 @@ ExtDateTable::ExtDateTable(TQWidget *parent, ExtDate date_, const char* name, WF
if(!date_.isValid())
{
kdDebug() << "ExtDateTable ctor: WARNING: Given date is invalid, using current date." << endl;
- date_=ExtDate::tqcurrentDate();
+ date_=ExtDate::currentDate();
}
setFocusPolicy( TQWidget::StrongFocus );
setNumRows(7); // 6 weeks max + headline
@@ -204,7 +204,7 @@ ExtDateTable::paintCell(TQPainter *painter, int row, int col)
normalday=false;
TQBrush brushTitle();
- TQBrush brushInvertTitle(tqcolorGroup().base());
+ TQBrush brushInvertTitle(colorGroup().base());
TQColor titleColor(isEnabled()?( KGlobalSettings::activeTitleColor() ):( KGlobalSettings::inactiveTitleColor() ) );
TQColor textColor(isEnabled()?( KGlobalSettings::activeTextColor() ):( KGlobalSettings::inactiveTextColor() ) );
if (!normalday)
@@ -221,7 +221,7 @@ ExtDateTable::paintCell(TQPainter *painter, int row, int col)
}
painter->drawText(0, 0, w, h-1, AlignCenter,
d->calendar->weekDayName(daynum, true), -1, &rect);
- painter->setPen(tqcolorGroup().text());
+ painter->setPen(colorGroup().text());
painter->moveTo(0, h-1);
painter->lineTo(w-1, h-1);
// ----- draw the weekday:
@@ -238,7 +238,7 @@ ExtDateTable::paintCell(TQPainter *painter, int row, int col)
// ° painting a day of the previous month or
// ° painting a day of the following month
// TODO: don't hardcode gray here! Use a color with less contrast to the background than normal text.
- painter->setPen( tqcolorGroup().mid() );
+ painter->setPen( colorGroup().mid() );
// painter->setPen(gray);
} else { // paint a day of the current month
if ( d->useCustomColors )
@@ -263,9 +263,9 @@ ExtDateTable::paintCell(TQPainter *painter, int row, int col)
}
painter->setPen( mode->fgColor );
} else
- painter->setPen(tqcolorGroup().text());
+ painter->setPen(colorGroup().text());
} else //if ( firstWeekDay < 4 ) // <- this doesn' make sense at all!
- painter->setPen(tqcolorGroup().text());
+ painter->setPen(colorGroup().text());
}
pen=painter->pen();
@@ -276,19 +276,19 @@ ExtDateTable::paintCell(TQPainter *painter, int row, int col)
if( ((offset+dy) == (pos+1)) && hasFocus())
{
// draw the currently selected date
- painter->setPen(tqcolorGroup().highlight());
- painter->setBrush(tqcolorGroup().highlight());
- pen=tqcolorGroup().highlightedText();
+ painter->setPen(colorGroup().highlight());
+ painter->setBrush(colorGroup().highlight());
+ pen=colorGroup().highlightedText();
} else {
painter->setBrush(paletteBackgroundColor());
painter->setPen(paletteBackgroundColor());
-// painter->setBrush(tqcolorGroup().base());
-// painter->setPen(tqcolorGroup().base());
+// painter->setBrush(colorGroup().base());
+// painter->setPen(colorGroup().base());
}
- if ( pCellDate == ExtDate::tqcurrentDate() )
+ if ( pCellDate == ExtDate::currentDate() )
{
- painter->setPen(tqcolorGroup().text());
+ painter->setPen(colorGroup().text());
}
if ( paintRect ) painter->drawRect(0, 0, w, h);
@@ -347,7 +347,7 @@ ExtDateTable::keyPressEvent( TQKeyEvent *e )
setDate(date.addDays(1));
return;
case Key_N:
- setDate(ExtDate::tqcurrentDate());
+ setDate(ExtDate::currentDate());
return;
case Key_Return:
case Key_Enter:
@@ -390,7 +390,7 @@ ExtDateTable::setFontSize(int size)
maxCell.setHeight(QMAX(maxCell.height(), rect.height()));
}
// ----- compare with a real wide number and add some space:
- rect=metrics.boundingRect(TQString::tqfromLatin1("88"));
+ rect=metrics.boundingRect(TQString::fromLatin1("88"));
maxCell.setWidth(QMAX(maxCell.width()+2, rect.width()));
maxCell.setHeight(QMAX(maxCell.height()+4, rect.height()));
}
@@ -494,7 +494,7 @@ ExtDateTable::setDate(const ExtDate& date_)
numDaysPrevMonth=d->calendar->daysInMonth(temp);
if(changed)
{
- tqrepaintContents(false);
+ repaintContents(false);
}
return true;
}
@@ -505,28 +505,28 @@ ExtDateTable::getDate() const
return date;
}
// what are those tqrepaintContents() good for? (pfeiffer)
void ExtDateTable::focusInEvent( TQFocusEvent *e )
{
-// tqrepaintContents(false);
+// repaintContents(false);
TQGridView::focusInEvent( e );
}
void ExtDateTable::focusOutEvent( TQFocusEvent *e )
{
-// tqrepaintContents(false);
+// repaintContents(false);
TQGridView::focusOutEvent( e );
}
QSize
-ExtDateTable::tqsizeHint() const
+ExtDateTable::sizeHint() const
{
if(maxCell.height()>0 && maxCell.width()>0)
{
return TQSize(maxCell.width()*numCols()+2*frameWidth(),
(maxCell.height()+2)*numRows()+2*frameWidth());
} else {
- kdDebug() << "ExtDateTable::tqsizeHint: obscure failure - " << endl;
+ kdDebug() << "ExtDateTable::sizeHint: obscure failure - " << endl;
return TQSize(-1, -1);
}
}
@@ -554,7 +554,7 @@ void ExtDateTable::setCustomDatePainting(const ExtDate &date, const TQColor &fgC
mode->fgColor=fgColor;
mode->bgColor=bgColor;
- d->customPaintingModes.tqreplace( date.toString(), mode );
+ d->customPaintingModes.replace( date.toString(), mode );
d->useCustomColors=true;
update();
}
@@ -617,7 +617,7 @@ ExtDateInternalWeekSelector::setMaxWeek(int max)
}
// ### CFM To avoid binary incompatibility.
// In future releases, remove this and tqreplace by a ExtDate
// private member, needed in ExtDateInternalMonthPicker::paintCell
class ExtDateInternalMonthPicker::ExtDateInternalMonthPrivate {
public:
@@ -677,7 +677,7 @@ ExtDateInternalMonthPicker::ExtDateInternalMonthPicker
}
QSize
-ExtDateInternalMonthPicker::tqsizeHint() const
+ExtDateInternalMonthPicker::sizeHint() const
{
return TQSize((max.width()+6)*numCols()+2*frameWidth(),
(max.height()+6)*numRows()+2*frameWidth());
@@ -779,7 +779,7 @@ ExtDateInternalMonthPicker::contentsMouseMoveEvent(TQMouseEvent *e)
updateCell( row, col /*, false */ ); // mark the new active cell
}
}
- if ( tmpRow > -1 ) // tqrepaint the former active cell
+ if ( tmpRow > -1 ) // repaint the former active cell
updateCell( tmpRow, tmpCol /*, true */ );
}
}
@@ -888,7 +888,7 @@ KPopupFrame::keyPressEvent(TQKeyEvent* e)
if(e->key()==Key_Escape)
{
result=0; // rejected
- tqApp->exit_loop();
+ qApp->exit_loop();
}
}
@@ -896,7 +896,7 @@ void
KPopupFrame::close(int r)
{
result=r;
- tqApp->exit_loop();
+ qApp->exit_loop();
}
void
@@ -947,8 +947,8 @@ int
KPopupFrame::exec(TQPoint pos)
{
popup(pos);
- tqrepaint();
- tqApp->enter_loop();
+ repaint();
+ qApp->enter_loop();
hide();
return result;
}
@@ -505,28 +505,28 @@ ExtDateTable::getDate() const
return date;
}
-// what are those tqrepaintContents() good for? (pfeiffer)
+// what are those repaintContents() good for? (pfeiffer)
void ExtDateTable::focusInEvent( TQFocusEvent *e )
{
@@ -617,7 +617,7 @@ ExtDateInternalWeekSelector::setMaxWeek(int max)
}
// ### CFM To avoid binary incompatibility.
-// In future releases, remove this and tqreplace by a ExtDate
+// In future releases, remove this and replace by a ExtDate
// private member, needed in ExtDateInternalMonthPicker::paintCell
class ExtDateInternalMonthPicker::ExtDateInternalMonthPrivate {
diff --git a/libkdeedu/extdate/extdatetbl.h b/libkdeedu/extdate/extdatetbl.h
index cf768e37..8aa3281a 100644
--- a/libkdeedu/extdate/extdatetbl.h
+++ b/libkdeedu/extdate/extdatetbl.h
@@ -99,7 +99,7 @@ public:
/**
* The size hint.
*/
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
/**
* Return the result. 0 means no selection (reject()), 1..12 are the
* months.
@@ -273,7 +273,7 @@ public:
* The constructor.
*/
ExtDateTable(TQWidget *parent=0,
- ExtDate date=ExtDate::tqcurrentDate(),
+ ExtDate date=ExtDate::currentDate(),
const char* name=0, WFlags f=0);
/**
@@ -286,9 +286,9 @@ public:
* To save some time, the size of the largest used cell content is
* calculated in each paintCell() call, since all calculations have
* to be done there anyway. The size is stored in maxCell. The
* tqsizeHint() simply returns a multiple of maxCell.
*/
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
/**
* Set the font size of the date table.
*/
@@ -286,9 +286,9 @@ public:
* calculated in each paintCell() call, since all calculations have
* to be done there anyway. The size is stored in maxCell. The
- * tqsizeHint() simply returns a multiple of maxCell.
+ * sizeHint() simply returns a multiple of maxCell.
*/
diff --git a/libkdeedu/extdate/extdatetime.cpp b/libkdeedu/extdate/extdatetime.cpp
index 97d8a4bd..fe32cf91 100644
--- a/libkdeedu/extdate/extdatetime.cpp
+++ b/libkdeedu/extdate/extdatetime.cpp
@@ -212,7 +212,7 @@ int ExtDate::weekNumber( int *yearNum ) const
if ( day1.daysTo( *this ) < 0 ) {
if ( yearNum ) *yearNum = year() - 1;
//The last week of the year always tqcontains Dec 28th (ISO 8601)
ExtDate lastDec28( year()-1, 12, 28 );
return lastDec28.weekNumber();
}
@@ -293,16 +293,16 @@ TQString ExtDate::toString( const TQString& format ) const
TQString result( format );
- result.tqreplace( "%Y", TQString().sprintf( "%d", year() ) );
- result.tqreplace( "%y", TQString().sprintf( "%02d", (year() % 100) ) );
- result.tqreplace( "%n", TQString().sprintf( "%d", month() ) );
- result.tqreplace( "%m", TQString().sprintf( "%02d", month() ) );
- result.tqreplace( "%e", TQString().sprintf( "%d", day() ) );
- result.tqreplace( "%d", TQString().sprintf( "%02d", day() ) );
- result.tqreplace( "%b", shortMonthName( month() ) );
- result.tqreplace( "%B", longMonthName( month() ) );
- result.tqreplace( "%a", shortDayName( dayOfWeek() ) );
- result.tqreplace( "%A", longDayName( dayOfWeek() ) );
+ result.replace( "%Y", TQString().sprintf( "%d", year() ) );
+ result.replace( "%y", TQString().sprintf( "%02d", (year() % 100) ) );
+ result.replace( "%n", TQString().sprintf( "%d", month() ) );
+ result.replace( "%m", TQString().sprintf( "%02d", month() ) );
+ result.replace( "%e", TQString().sprintf( "%d", day() ) );
+ result.replace( "%d", TQString().sprintf( "%02d", day() ) );
+ result.replace( "%b", shortMonthName( month() ) );
+ result.replace( "%B", longMonthName( month() ) );
+ result.replace( "%a", shortDayName( dayOfWeek() ) );
+ result.replace( "%A", longDayName( dayOfWeek() ) );
return result;
}
@@ -377,7 +377,7 @@ int ExtDate::daysTo( const ExtDate & a_date) const
return a_date.jd() - jd();
}
-ExtDate ExtDate::tqcurrentDate(Qt::TimeSpec ts)
+ExtDate ExtDate::currentDate(Qt::TimeSpec ts)
{
time_t a_current_time;
struct tm a_current_time_tm;
@@ -551,7 +551,7 @@ int ExtDate::dayOfYear(int y, int m, int d)
\ingroup time
- A ExtDateTime object tqcontains a calendar date and a clock time (a
+ A ExtDateTime object contains a calendar date and a clock time (a
"datetime"). It is a combination of the ExtDate and TQTime classes.
It can read the current datetime from the system clock. It
provides functions for comparing datetimes and for manipulating a
@@ -559,7 +559,7 @@ int ExtDate::dayOfYear(int y, int m, int d)
A ExtDateTime object is typically created either by giving a date
and time explicitly in the constructor, or by using the static
- function tqcurrentDateTime(), which returns a ExtDateTime object set
+ function currentDateTime(), which returns a ExtDateTime object set
to the system clock's time. The date and time can be changed with
setDate() and setTime(). A datetime can also be set using the
setTime_t() function, which takes a POSIX-standard "number of
@@ -833,13 +833,13 @@ TQString ExtDateTime::toString( const TQString& format ) const
int h = time().hour();
- result.tqreplace( "%H", TQString().sprintf( "%02d", h ) );
- result.tqreplace( "%k", TQString().sprintf( "%d", h ) );
- result.tqreplace( "%I", TQString().sprintf( "%02d", ( h > 12 ) ? h-12 : h ) );
- result.tqreplace( "%l", TQString().sprintf( "%d", ( h > 12 ) ? h-12 : h ) );
- result.tqreplace( "%M", TQString().sprintf( "%02d", time().minute() ) );
- result.tqreplace( "%S", TQString().sprintf( "%02d", time().second() ) );
- result.tqreplace( "%p", TQString().sprintf( "%s", ( h > 12 ) ? "pm" : "am" ) );
+ result.replace( "%H", TQString().sprintf( "%02d", h ) );
+ result.replace( "%k", TQString().sprintf( "%d", h ) );
+ result.replace( "%I", TQString().sprintf( "%02d", ( h > 12 ) ? h-12 : h ) );
+ result.replace( "%l", TQString().sprintf( "%d", ( h > 12 ) ? h-12 : h ) );
+ result.replace( "%M", TQString().sprintf( "%02d", time().minute() ) );
+ result.replace( "%S", TQString().sprintf( "%02d", time().second() ) );
+ result.replace( "%p", TQString().sprintf( "%s", ( h > 12 ) ? "pm" : "am" ) );
return result;
}
@@ -933,7 +933,7 @@ int ExtDateTime::daysTo( const ExtDateTime &dt ) const
Example:
\code
- ExtDateTime dt = ExtDateTime::tqcurrentDateTime();
+ ExtDateTime dt = ExtDateTime::currentDateTime();
ExtDateTime xmas( ExtDate(dt.date().year(),12,24), TQTime(17,00) );
kdDebug( ) << "There are " << dt.secsTo(xmas) << " seconds to Christmas" << endl;
\endcode
@@ -1023,28 +1023,28 @@ bool ExtDateTime::operator>=( const ExtDateTime &dt ) const
Returns the current datetime, as reported by the system clock.
- \sa ExtDate::tqcurrentDate(), TQTime::currentTime()
+ \sa ExtDate::currentDate(), TQTime::currentTime()
*/
-ExtDateTime ExtDateTime::tqcurrentDateTime()
+ExtDateTime ExtDateTime::currentDateTime()
{
- return tqcurrentDateTime( Qt::LocalTime );
+ return currentDateTime( Qt::LocalTime );
}
/*!
Returns the current datetime, as reported by the system clock, for the
TimeSpec \a ts. The default TimeSpec is LocalTime.
- \sa ExtDate::tqcurrentDate(), TQTime::currentTime(), Qt::TimeSpec
+ \sa ExtDate::currentDate(), TQTime::currentTime(), Qt::TimeSpec
*/
-ExtDateTime ExtDateTime::tqcurrentDateTime( Qt::TimeSpec ts )
+ExtDateTime ExtDateTime::currentDateTime( Qt::TimeSpec ts )
{
ExtDateTime dt;
- dt.setDate( ExtDate::tqcurrentDate(ts) );
+ dt.setDate( ExtDate::currentDate(ts) );
TQTime t = t.currentTime(ts);
if ( t.hour()==0 && t.minute()==0 ) // midnight or right after?
- dt.setDate( ExtDate::tqcurrentDate(ts) ); // fetch date again
+ dt.setDate( ExtDate::currentDate(ts) ); // fetch date again
dt.setTime( t );
return dt;
}
@@ -1084,7 +1084,7 @@ ExtDateTime ExtDateTime::fromString( const TQString& s, Qt::DateFormat f )
}
if ( f == Qt::ISODate ) {
- if ( s.length() <= 10 || ! s.tqcontains( ':' ) ) { //no time specified
+ if ( s.length() <= 10 || ! s.contains( ':' ) ) { //no time specified
TQTime t = TQTime(0,0,0);
return ExtDateTime( ExtDate::fromString( s.mid(0,10), Qt::ISODate ) );
} else {
@@ -1099,7 +1099,7 @@ ExtDateTime ExtDateTime::fromString( const TQString& s, Qt::DateFormat f )
TQTime time;
TQString sd = s;
int hour, minute, second;
- int pivot = s.find( TQRegExp(TQString::tqfromLatin1("[0-9][0-9]:[0-9][0-9]:[0-9][0-9]")) );
+ int pivot = s.find( TQRegExp(TQString::fromLatin1("[0-9][0-9]:[0-9][0-9]:[0-9][0-9]")) );
if ( pivot != -1 ) {
hour = s.mid( pivot, 2 ).toInt();
minute = s.mid( pivot+3, 2 ).toInt();
@@ -1123,12 +1123,12 @@ ExtDateTime ExtDateTime::fromString( const TQString& s, Qt::DateFormat f )
#ifndef QT_NO_DATASTREAM
KDE_EXPORT TQDataStream &operator<<( TQDataStream & ostream, const ExtDate & date)
{
- return ostream << (TQ_UINT32)(date.jd());
+ return ostream << (Q_UINT32)(date.jd());
}
KDE_EXPORT TQDataStream &operator>>( TQDataStream & ostream, ExtDate & date)
{
- TQ_UINT32 julday;
+ Q_UINT32 julday;
ostream >> julday;
date.setJD( julday );
return ostream;
@@ -212,7 +212,7 @@ int ExtDate::weekNumber( int *yearNum ) const
if ( day1.daysTo( *this ) < 0 ) {
if ( yearNum ) *yearNum = year() - 1;
- //The last week of the year always tqcontains Dec 28th (ISO 8601)
+ //The last week of the year always contains Dec 28th (ISO 8601)
ExtDate lastDec28( year()-1, 12, 28 );
return lastDec28.weekNumber();
diff --git a/libkdeedu/extdate/extdatetimeedit.cpp b/libkdeedu/extdate/extdatetimeedit.cpp
index f2db94fb..203f1dbb 100644
--- a/libkdeedu/extdate/extdatetimeedit.cpp
+++ b/libkdeedu/extdate/extdatetimeedit.cpp
@@ -135,7 +135,7 @@ static void readLocaleSettings()
#ifndef Q_WS_WIN
TQString sep = d.mid( QMIN( dpos, mpos ) + 2, QABS( dpos - mpos ) - 2 );
- if ( d.tqcontains( sep ) == 2 ) {
+ if ( d.contains( sep ) == 2 ) {
*lDateSep = sep;
}
#endif
@@ -266,7 +266,7 @@ public:
{
int fw = 0;
if ( frm )
- fw = style.tqpixelMetric(TQStyle::PM_DefaultFrameWidth);
+ fw = style.pixelMetric(TQStyle::PM_DefaultFrameWidth);
parag->truncate( 0 );
parag->append( txt );
@@ -295,7 +295,7 @@ public:
TQRect r( rect.x(), rect.y(), rect.width() - 2 * ( 2 + fw ), rect.height() );
parag->pseudoDocument()->docRect = r;
- parag->tqinvalidate(0);
+ parag->invalidate(0);
parag->format();
int xoff = 2 + fw - offset;
@@ -411,7 +411,7 @@ bool ExtDateTimeEditor::event( TQEvent *e )
{
if ( e->type() == TQEvent::FocusIn || e->type() == TQEvent::FocusOut ) {
if ( e->type() == TQEvent::FocusOut )
- tqApp->sendEvent( cw, e );
+ qApp->sendEvent( cw, e );
update( rect() );
} else if ( e->type() == TQEvent::AccelOverride ) {
TQKeyEvent* ke = (TQKeyEvent*) e;
@@ -460,9 +460,9 @@ void ExtDateTimeEditor::paintEvent( TQPaintEvent * )
QSharedDoubleBuffer buffer( this );
const TQBrush &bg =
- tqcolorGroup().brush( isEnabled() ? TQColorGroup::Base : TQColorGroup::Background );
+ colorGroup().brush( isEnabled() ? TQColorGroup::Base : TQColorGroup::Background );
buffer.painter()->fillRect( 0, 0, width(), height(), bg );
- d->paint( txt, hasFocus(), *buffer.painter(), tqcolorGroup(), rect(),
+ d->paint( txt, hasFocus(), *buffer.painter(), colorGroup(), rect(),
style() );
buffer.end();
}
@@ -492,7 +492,7 @@ void ExtDateTimeEditor::mousePressEvent( TQMouseEvent *e )
int sec = sectionAt( p );
if ( sec != -1 ) {
cw->setFocusSection( sec );
- tqrepaint( rect(), FALSE );
+ repaint( rect(), FALSE );
}
}
@@ -508,13 +508,13 @@ bool ExtDateTimeEditor::eventFilter( TQObject *o, TQEvent *e )
case Key_Right:
if ( d->focusSection() < (int)d->sectionCount()-1 ) {
if ( cw->setFocusSection( focusSection()+1 ) )
- tqrepaint( rect(), FALSE );
+ repaint( rect(), FALSE );
}
return TRUE;
case Key_Left:
if ( d->focusSection() > 0 ) {
if ( cw->setFocusSection( focusSection()-1 ) )
- tqrepaint( rect(), FALSE );
+ repaint( rect(), FALSE );
}
return TRUE;
case Key_Up:
@@ -544,12 +544,12 @@ bool ExtDateTimeEditor::eventFilter( TQObject *o, TQEvent *e )
::qt_cast<ExtDateTimeEdit*>(w) )
break;
hadDateEdit = hadDateEdit || ::qt_cast<ExtDateEdit*>(w);
- w = w->tqparentWidget();
+ w = w->parentWidget();
}
if ( w ) {
if ( !::qt_cast<ExtDateTimeEdit*>(w) ) {
- w = w->tqparentWidget();
+ w = w->parentWidget();
} else {
ExtDateTimeEdit *ed = (ExtDateTimeEdit*)w;
if ( hadDateEdit && ke->key() == Key_Tab ) {
@@ -560,11 +560,11 @@ bool ExtDateTimeEditor::eventFilter( TQObject *o, TQEvent *e )
return TRUE;
} else {
while ( w && !::qt_cast<ExtDateTimeEdit*>(w) )
- w = w->tqparentWidget();
+ w = w->parentWidget();
}
}
- tqApp->sendEvent( w, e );
+ qApp->sendEvent( w, e );
return TRUE;
}
} break;
@@ -574,7 +574,7 @@ bool ExtDateTimeEditor::eventFilter( TQObject *o, TQEvent *e )
// do the same thing as KEY_RIGHT when the user presses the separator key
if ( d->focusSection() < 2 ) {
if ( cw->setFocusSection( focusSection()+1 ) )
- tqrepaint( rect(), FALSE );
+ repaint( rect(), FALSE );
}
return TRUE;
} else if ( !txt.isEmpty() && ::qt_cast<QTimeEdit*>(cw) && focusSection() == (int) d->sectionCount()-1 ) {
@@ -767,9 +767,9 @@ public:
with a date, e.g.
\code
- ExtDateEdit *dateEdit = new ExtDateEdit( ExtDate::tqcurrentDate(), this );
- dateEdit->setRange( ExtDate::tqcurrentDate().addDays( -365 ),
- ExtDate::tqcurrentDate().addDays( 365 ) );
+ ExtDateEdit *dateEdit = new ExtDateEdit( ExtDate::currentDate(), this );
+ dateEdit->setRange( ExtDate::currentDate().addDays( -365 ),
+ ExtDate::currentDate().addDays( 365 ) );
dateEdit->setOrder( ExtDateEdit::MDY );
dateEdit->setAutoAdvance( TRUE );
\endcode
@@ -883,7 +883,7 @@ void ExtDateEdit::init()
d->max = ExtDate( 50000, 12, 31 );
d->changed = FALSE;
- tqsetSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Fixed );
+ setSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Fixed );
refcount++;
}
@@ -997,11 +997,11 @@ void ExtDateEdit::resizeEvent( TQResizeEvent * )
/*! \reimp
*/
-TQSize ExtDateEdit::tqsizeHint() const
+TQSize ExtDateEdit::sizeHint() const
{
constPolish();
TQFontMetrics fm( font() );
- int fw = style().tqpixelMetric( TQStyle::PM_DefaultFrameWidth, this );
+ int fw = style().pixelMetric( TQStyle::PM_DefaultFrameWidth, this );
int h = QMAX( fm.lineSpacing(), 14 ) + 2;
int w = 2 + fm.width( '9' ) * 8 + fm.width( d->ed->separator() ) * 2
+ d->controls->upRect().width() + fw * 4;
@@ -1012,9 +1012,9 @@ TQSize ExtDateEdit::tqsizeHint() const
/*! \reimp
*/
-TQSize ExtDateEdit::tqminimumSizeHint() const
+TQSize ExtDateEdit::minimumSizeHint() const
{
- return tqsizeHint();
+ return sizeHint();
}
@@ -1160,7 +1160,7 @@ void ExtDateEdit::setOrder( ExtDateEdit::Order order )
}
if ( isVisible() )
- d->ed->tqrepaint( d->ed->rect(), FALSE );
+ d->ed->repaint( d->ed->rect(), FALSE );
}
@@ -1198,7 +1198,7 @@ void ExtDateEdit::stepUp()
emit valueChanged( date() );
}
- d->ed->tqrepaint( d->ed->rect(), FALSE );
+ d->ed->repaint( d->ed->rect(), FALSE );
}
@@ -1232,7 +1232,7 @@ void ExtDateEdit::stepDown()
emit valueChanged( date() );
}
- d->ed->tqrepaint( d->ed->rect(), FALSE );
+ d->ed->repaint( d->ed->rect(), FALSE );
}
/*!
@@ -1295,7 +1295,7 @@ void ExtDateEdit::setDay( int day )
If the date property is not valid, the editor displays all zeroes
and ExtDateEdit::date() will return an invalid date. It is strongly
recommended that the editor is given a default date value (e.g.
- tqcurrentDate()). That way, attempts to set the date property to an
+ currentDate()). That way, attempts to set the date property to an
invalid date will fail.
When changing the date property, if the date is less than
@@ -1319,7 +1319,7 @@ void ExtDateEdit::setDate( const ExtDate& date )
emit valueChanged( date );
}
d->changed = FALSE;
- d->ed->tqrepaint( d->ed->rect(), FALSE );
+ d->ed->repaint( d->ed->rect(), FALSE );
}
ExtDate ExtDateEdit::date() const
@@ -1341,8 +1341,8 @@ ExtDate ExtDateEdit::date() const
bool ExtDateEdit::outOfRange( int y, int m, int d ) const
{
if ( ExtDate::isValid( y, m, d ) ) {
- ExtDate tqcurrentDate( y, m, d );
- if ( tqcurrentDate > maxValue() || tqcurrentDate < minValue() ) {
+ ExtDate currentDate( y, m, d );
+ if ( currentDate > maxValue() || currentDate < minValue() ) {
//## outOfRange should set overwrite?
return TRUE;
}
@@ -1454,8 +1454,8 @@ void ExtDateEdit::addNumber( int sec, int num )
emit valueChanged( date() );
}
d->overwrite = overwrite;
- d->timerId = startTimer( tqApp->doubleClickInterval()*4 );
- d->ed->tqrepaint( d->ed->rect(), FALSE );
+ d->timerId = startTimer( qApp->doubleClickInterval()*4 );
+ d->ed->repaint( d->ed->rect(), FALSE );
}
@@ -1502,7 +1502,7 @@ void ExtDateEdit::fix()
changed = TRUE;
}
- int currentYear = ExtDate::tqcurrentDate().year();
+ int currentYear = ExtDate::currentDate().year();
int year = d->y;
/* No longer valid for extended dates
if ( year < 100 ) {
@@ -1608,7 +1608,7 @@ void ExtDateEdit::removeFirstNumber( int sec )
d->d = txt.toInt();
d->dayCache = d->d;
}
- d->ed->tqrepaint( d->ed->rect(), FALSE );
+ d->ed->repaint( d->ed->rect(), FALSE );
}
/*! \reimp
@@ -1634,7 +1634,7 @@ void ExtDateEdit::removeLastNumber( int sec )
d->d = txt.toInt();
d->dayCache = d->d;
}
- d->ed->tqrepaint( d->ed->rect(), FALSE );
+ d->ed->repaint( d->ed->rect(), FALSE );
}
/*!
@@ -1791,7 +1791,7 @@ public:
// d->max = TQTime( 23, 59, 59 );
// d->changed = FALSE;
//
-// tqsetSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Fixed );
+// setSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Fixed );
//
// refcount++;
// }
@@ -1909,7 +1909,7 @@ public:
// emit valueChanged( time );
// }
// d->changed = FALSE;
-// d->ed->tqrepaint( d->ed->rect(), FALSE );
+// d->ed->repaint( d->ed->rect(), FALSE );
// }
//
// TQTime QTimeEdit::time() const
@@ -2039,7 +2039,7 @@ public:
// d->changed = TRUE;
// emit valueChanged( time() );
// }
-// d->ed->tqrepaint( d->ed->rect(), FALSE );
+// d->ed->repaint( d->ed->rect(), FALSE );
// }
//
//
@@ -2088,7 +2088,7 @@ public:
// d->changed = TRUE;
// emit valueChanged( time() );
// }
-// d->ed->tqrepaint( d->ed->rect(), FALSE );
+// d->ed->repaint( d->ed->rect(), FALSE );
// }
//
//
@@ -2214,12 +2214,12 @@ public:
// if ( lAM )
// txt = *lAM;
// else
-// txt = TQString::tqfromLatin1( "AM" );
+// txt = TQString::fromLatin1( "AM" );
// } else {
// if ( lPM )
// txt = *lPM;
// else
-// txt = TQString::tqfromLatin1( "PM" );
+// txt = TQString::fromLatin1( "PM" );
// }
// break;
// default:
@@ -2369,8 +2369,8 @@ public:
// if ( accepted )
// emit valueChanged( time() );
// d->overwrite = overwrite;
-// d->timerId = startTimer( tqApp->doubleClickInterval()*4 );
-// d->ed->tqrepaint( d->ed->rect(), FALSE );
+// d->timerId = startTimer( qApp->doubleClickInterval()*4 );
+// d->ed->repaint( d->ed->rect(), FALSE );
// }
//
//
@@ -2410,7 +2410,7 @@ public:
// d->s = txt.toInt();
// break;
// }
-// d->ed->tqrepaint( d->ed->rect(), FALSE );
+// d->ed->repaint( d->ed->rect(), FALSE );
// }
//
// /*! \reimp
@@ -2445,7 +2445,7 @@ public:
// d->s = txt.toInt();
// break;
// }
-// d->ed->tqrepaint( d->ed->rect(), FALSE );
+// d->ed->repaint( d->ed->rect(), FALSE );
// }
//
// /*! \reimp
@@ -2457,11 +2457,11 @@ public:
//
// /*! \reimp
// */
// TQSize QTimeEdit::tqsizeHint() const
// {
// constPolish();
// TQFontMetrics fm( font() );
-// int fw = style().tqpixelMetric( TQStyle::PM_DefaultFrameWidth, this );
+// int fw = style().pixelMetric( TQStyle::PM_DefaultFrameWidth, this );
// int h = fm.lineSpacing() + 2;
// int w = 2 + fm.width( '9' ) * 6 + fm.width( d->ed->separator() ) * 2 +
// d->controls->upRect().width() + fw * 4;
@@ -2469,7 +2469,7 @@ public:
// if ( lAM )
// w += fm.width( *lAM ) + 4;
// else
-// w += fm.width( TQString::tqfromLatin1( "AM" ) ) + 4;
+// w += fm.width( TQString::fromLatin1( "AM" ) ) + 4;
// }
//
// return TQSize( w, QMAX(h + fw * 2,20) ).expandedTo( TQApplication::globalStrut() );
@@ -2477,9 +2477,9 @@ public:
//
// /*! \reimp
// */
// TQSize QTimeEdit::tqminimumSizeHint() const
// {
-// return tqsizeHint();
+// return sizeHint();
// }
//
// /*!
@@ -2534,9 +2534,9 @@ public:
It is recommended that the ExtDateTimeEdit is initialised with a
datetime, e.g.
\code
- ExtDateTimeEdit *dateTimeEdit = new ExtDateTimeEdit( ExtDateTime::tqcurrentDateTime(), this );
- dateTimeEdit->dateEdit()->setRange( ExtDateTime::tqcurrentDate(),
- ExtDateTime::tqcurrentDate().addDays( 7 ) );
+ ExtDateTimeEdit *dateTimeEdit = new ExtDateTimeEdit( ExtDateTime::currentDateTime(), this );
+ dateTimeEdit->dateEdit()->setRange( ExtDateTime::currentDate(),
+ ExtDateTime::currentDate().addDays( 7 ) );
\endcode
Here we've created a new ExtDateTimeEdit set to the current date and
time, and set the date to have a minimum date of now and a maximum
@@ -2600,8 +2600,8 @@ ExtDateTimeEdit::~ExtDateTimeEdit()
void ExtDateTimeEdit::resizeEvent( TQResizeEvent * )
{
- int dw = de->tqsizeHint().width();
- int tw = te->tqsizeHint().width();
+ int dw = de->sizeHint().width();
+ int tw = te->sizeHint().width();
int w = width();
int h = height();
int extra = w - ( dw + tw );
@@ -2620,10 +2620,10 @@ void ExtDateTimeEdit::resizeEvent( TQResizeEvent * )
/*! \reimp
*/
-TQSize ExtDateTimeEdit::tqminimumSizeHint() const
+TQSize ExtDateTimeEdit::minimumSizeHint() const
{
- TQSize dsh = de->tqminimumSizeHint();
- TQSize tsh = te->tqminimumSizeHint();
+ TQSize dsh = de->minimumSizeHint();
+ TQSize tsh = te->minimumSizeHint();
return TQSize( dsh.width() + tsh.width(),
QMAX( dsh.height(), tsh.height() ) );
}
@@ -2642,17 +2642,17 @@ void ExtDateTimeEdit::init()
connect( te, TQT_SIGNAL( valueChanged( const TQTime& ) ),
this, TQT_SLOT( newValue( const TQTime& ) ) );
setFocusProxy( de );
- tqsetSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Fixed );
+ setSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Fixed );
}
/*! \reimp
*/
-TQSize ExtDateTimeEdit::tqsizeHint() const
+TQSize ExtDateTimeEdit::sizeHint() const
{
constPolish();
- TQSize dsh = de->tqsizeHint();
- TQSize tsh = te->tqsizeHint();
+ TQSize dsh = de->sizeHint();
+ TQSize tsh = te->sizeHint();
return TQSize( dsh.width() + tsh.width(),
QMAX( dsh.height(), tsh.height() ) );
}
@@ -2457,11 +2457,11 @@ public:
// /*! \reimp
// */
-// TQSize QTimeEdit::tqsizeHint() const
+// TQSize QTimeEdit::sizeHint() const
// {
// constPolish();
@@ -2477,9 +2477,9 @@ public:
// /*! \reimp
// */
-// TQSize QTimeEdit::tqminimumSizeHint() const
+// TQSize QTimeEdit::minimumSizeHint() const
// {
diff --git a/libkdeedu/kdeeduplot/kplotwidget.h b/libkdeedu/kdeeduplot/kplotwidget.h
index 212c5234..5ed550ec 100644
--- a/libkdeedu/kdeeduplot/kplotwidget.h
+++ b/libkdeedu/kdeeduplot/kplotwidget.h
@@ -95,11 +95,11 @@ public:
*/
virtual void clearObjectList() { ObjectList.clear(); update(); }
/**@short tqreplace an item in the KPlotObject list.
*@param i the index of th item to be tqreplaced
*@param o pointer to the tqreplacement KPlotObject
*/
- virtual void tqreplaceObject( int i, KPlotObject *o ) { ObjectList.tqreplace( i, o ); }
+ virtual void replaceObject( int i, KPlotObject *o ) { ObjectList.replace( i, o ); }
/**@return the number of KPlotObjects in the list
*/
@@ -212,7 +212,7 @@ public:
KPlotAxis LeftAxis;
protected:
- /**@short the paint event handler, executed when update() or tqrepaint() is called.
+ /**@short the paint event handler, executed when update() or repaint() is called.
*/
virtual void paintEvent( TQPaintEvent* /* e */ );
@@ -95,11 +95,11 @@ public:
*/
virtual void clearObjectList() { ObjectList.clear(); update(); }
- /**@short tqreplace an item in the KPlotObject list.
- *@param i the index of th item to be tqreplaced
- *@param o pointer to the tqreplacement KPlotObject
+ /**@short replace an item in the KPlotObject list.
+ *@param i the index of th item to be replaced
+ *@param o pointer to the replacement KPlotObject
*/